#!/bin/sh
#
# Reformat a fault report to make it easier to read.
#
# Copyright 2024 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

xyzReformat () {
	outputWidth="77"
	headingWidth="15"
	if test "${reformatColour}" = "yes" && command -v tput >/dev/null 2>&1; then
		formatHeading="$(tput bold 2>/dev/null)"
		formatProblem="$(tput setaf 5 2>/dev/null; tput bold 2>/dev/null)"
		formatLowRiskFix="$(tput setaf 3 2>/dev/null)"
		formatHighRiskFix="$(tput setaf 1 2>/dev/null; tput bold 2>/dev/null)"
		formatManualFix="$(tput setaf 6 2>/dev/null; tput bold 2>/dev/null)"
		formatReset="$(tput sgr0 2>/dev/null)"
	else
		formatHeading=""
		formatProblem=""
		formatLowRiskFix=""
		formatHighRiskFix=""
		formatManualFix=""
		formatReset=""
	fi
	while IFS="$(printf "\t")" read -r faultFlag itemName faultProblem faultActions; do
		itemDescription=""
		itemDerivedFrom=""
		test -e "${workDir}/items/description/${itemName}" && read -r itemDescription < "${workDir}/items/description/${itemName}"
		test -n "${itemDescription}" || itemDescription="(unknown)"
		test -e "${workDir}/items/derivedFrom/${itemName}" && read -r itemDerivedFrom < "${workDir}/items/derivedFrom/${itemName}"

		case "${faultFlag}" in
		"a") faultFormat="${formatLowRiskFix}"; faultFlagDescription="Low risk automatic fix" ;;
		"R") faultFormat="${formatHighRiskFix}"; faultFlagDescription="Higher risk automatic fix" ;;
		"m") faultFormat="${formatManualFix}"; faultFlagDescription="Must be corrected manually" ;;
		"*") faultFormat=""; faultFlagDescription="(unknown flag)" ;;
		esac

		# Reformat the item description and problem so that they fit
		# the width, indenting overflow lines so they start in the
		# right place since the first line is prefixed by a heading.

		itemDescription="$(printf "%s\n" "${itemDescription}" | fmt -w $((outputWidth-headingWidth-2)) | sed '2,$s/^/ '"$(printf "%${headingWidth}s" "")"'/')"
		faultProblem="$(printf "%s\n" "${faultProblem}" | fmt -w $((outputWidth-headingWidth-2)) | sed '2,$s/^/ '"$(printf "%${headingWidth}s" "")"'/')"

		printf "%${outputWidth}s\n" "" | tr ' ' '*'
		printf "%s%-${headingWidth}s%s %s\n" "${formatHeading}" "Item name:" "${formatReset}" "${itemName}"
		printf "%s%-${headingWidth}s%s %s\n" "${formatHeading}" "Description:" "${formatReset}" "${itemDescription}"
		test -n "${itemDerivedFrom}" && printf "%s%-${headingWidth}s%s %s\n" "${formatHeading}" "Derived from:" "${formatReset}" "${itemDerivedFrom}"
		printf "%s%-${headingWidth}s%s %s%s%s\n" "${formatHeading}" "Fault found:" "${formatReset}" "${formatProblem}" "${faultProblem}" "${formatReset}"
		printf "%s%-${headingWidth}s%s (%s): %s%s%s\n" "${formatHeading}" "Fix type:" "${formatReset}" "${faultFlag}" "${faultFormat}" "${faultFlagDescription}" "${formatReset}"
		printf "\n%s%s%s\n\n" "${formatHeading}" "Actions:" "${formatReset}"
		printf "%s\n" "${faultActions}" | tr '|' '\n' | while read -r faultAction; do
			printf "%s\n" "${faultAction}" | fmt -w ${outputWidth} | sed '1s/^/ * /;2,$s/^/   /'
		done
		printf "\n"
	done
}
